==> icebear_v1_4_1.tar: classes/model/imager.class.php <==
<?php class imager extends baseobject { 
	
	protected static $fields=array(
		'name'=>validator::REQUIRED,
		'friendlyname'=>validator::REQUIRED,
		'manufacturer'=>validator::REQUIRED,
		'temperature'=>array(validator::REQUIRED, validator::INTEGER),
		'platecapacity'=>array(validator::REQUIRED, validator::INTEGER),
		'platesactive'=>array(validator::INTEGER),
		'platesexpired'=>array(validator::INTEGER),
		'alertlevel'=>array(validator::REQUIRED, validator::INTEGER),
		'warninglevel'=>array(validator::REQUIRED, validator::INTEGER),
		'manualimaging'=>validator::BOOLEAN
	);
	
	protected static $helpTexts=array(
		'name'=>'A unique identifier for the imager',
		'friendlyname'=>'A human-friendly mame like "20-degree imager"',
		'manufacturer'=>'The manufacturer name',
		'temperature'=>'The normal temperature in the imager',
		'platecapacity'=>'How many plates the imager can hold',
		'platesactive'=>'How many plates in the imager have inspections scheduled',
		'platesexpired'=>'How many plates in the imager have no inspections scheduled',
		'alertlevel'=>'Plate count when imager is "filling up"',
		'warninglevel'=>'Plate count when imager is "almost full"',
		'manualimaging'=>'Imager is for manually-added plate inspections, e.g., microscope'
	);
	
	public static function create($request=array()){
		$project=project::getByName(project::SHARED);
		$request['projectid']=$project['id'];
        return parent::createByClassName($request,'imager');
	}

    /**
     * @param $id
     * @param array $request
     * @return array
     * @throws BadRequestException
     * @throws NotFoundException
     * @throws ServerException
     * @noinspection PhpUnused
     */
	public static function getimagingsessions($id, $request=array()){
		return imagingsession::getByProperty('imagerid', $id, $request);
	}

    /**
     * @param $id
     * @param array $request
     * @return array
     * @throws BadRequestException
     * @throws NotFoundException
     * @throws ServerException
     * @noinspection PhpUnused
     */
	public static function getplates($id, $request=array()){
		return plate::getByProperty('locationid', $id, $request);
	}

    /**
     * @param $id
     * @param array $request
     * @return array
     * @throws BadRequestException
     * @throws NotFoundException
     * @throws ServerException
     * @noinspection PhpUnused
     */
	public static function getimagerloadlogs($id, $request=array()){
		return imagerloadlog::getByProperty('imagerid', $id, $request);
	}
	
	
}

==> icebear_v1_11_0.tar: classes/model/imager.class.php <==
<?php class imager extends baseobject { 
	
	protected static $fields=array(
		'name'=>validator::REQUIRED,
		'friendlyname'=>validator::REQUIRED,
		'manufacturer'=>validator::REQUIRED,
		'temperature'=>array(validator::REQUIRED, validator::INTEGER),
		'platecapacity'=>array(validator::REQUIRED, validator::INTEGER),
		'platesactive'=>array(validator::INTEGER),
		'platesexpired'=>array(validator::INTEGER),
		'alertlevel'=>array(validator::REQUIRED, validator::INTEGER),
		'warninglevel'=>array(validator::REQUIRED, validator::INTEGER),
        'manualimaging'=>validator::BOOLEAN,
		'isinuse'=>validator::BOOLEAN
	);
	
	protected static $helpTexts=array(
		'name'=>'A unique identifier for the imager',
		'friendlyname'=>'A human-friendly name like "20-degree imager"',
		'manufacturer'=>'The manufacturer name',
		'temperature'=>'The normal temperature in the imager',
		'platecapacity'=>'How many plates the imager can hold',
		'platesactive'=>'How many plates in the imager have inspections scheduled',
		'platesexpired'=>'How many plates in the imager have no inspections scheduled',
		'alertlevel'=>'Plate count when imager is "filling up"',
		'warninglevel'=>'Plate count when imager is "almost full"',
		'manualimaging'=>'Imager is for manually-added plate inspections, e.g., microscope',
        'isinuse'=>'Whether the imager is installed. Set false when retiring the imager.'
	);
	
	public static function create(array $request=array()): array {
		$project=project::getByName(baseproject::SHARED);
		if(!$project){
			throw new NotFoundException('Could not read shared project');
		}
		$request['projectid']=$project['id'];
        return parent::createByClassName($request,'imager');
	}

    public static function update($id, $request=array()): array {
        if(isset($request['isinuse']) && 0===1*$request['isinuse']){
            $plates=imager::getplates($id, $request);
            if(isset($plates['rows'])){
                foreach($plates['rows'] as $plate){
                    plate::update($plate['id'],['locationid'=>database::$nullValue]);
                }
            }
        }
        return parent::update($id, $request);
    }

    /**
     * @param $id
     * @param array $request
     * @return array
     * @throws BadRequestException
     * @throws NotFoundException
     * @throws ServerException
     * @noinspection PhpUnused
     */
	public static function getimagingsessions($id, $request=array()){
		return imagingsession::getByProperty('imagerid', $id, $request);
	}

    /**
     * @param $id
     * @param array $request
     * @return array
     * @throws BadRequestException
     * @throws NotFoundException
     * @throws ServerException
     * @noinspection PhpUnused
     */
	public static function getplates($id, $request=array()){
		return plate::getByProperty('locationid', $id, $request);
	}

    /**
     * @param $id
     * @param array $request
     * @return array
     * @throws BadRequestException
     * @throws NotFoundException
     * @throws ServerException
     * @noinspection PhpUnused
     */
	public static function getimagerloadlogs($id, $request=array()){
		return imagerloadlog::getByProperty('imagerid', $id, $request);
	}
	
	
}
